@@ -46,6 +46,10 @@
 #'
 
 POSIXct2Character <- function(x, fmt="%Y-%m-%d %H:%M:%OS3") {
+
+  checkmate::assertPOSIXct(x)
+  checkmate::assertCharacter(fmt, any.missing=FALSE, max.len=1)
+
   pos <- gregexpr("%OS[[:digit:]]+", fmt)[[1]]
   if (pos > 0) {
     pos <- pos + c(3L, attr(pos, "match.length"))
